@@ -5,7 +5,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 /*jslint vars: true, browser: true */
 /*global jQuery, tiddlyweb, confirm, prompt */
 //
-// version 0.5.11
+// version 0.5.12
 (function($, window) {
 	"use strict";
 
@@ -85,8 +85,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 		}
 		var container = $("<div />").appendTo(msgArea)[0];
 		var label = error ? ts.locale.tryAgain : ts.locale.success;
-		$("<a />").text(label).click(function(ev) {
-			var form = $("form", $(ev.target).parents());
+		$("<a />").text(label).click(function() {
 			resetMessage(form);
 		}).appendTo(container);
 	}
@@ -332,8 +331,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 				var space = new tiddlyweb.Space(spaceName, "/");
 				space.create(callback, errback);
 			} else {
-				displayMessage(form, ts.locale.invalidSpaceError,
-					true, { selector: "[name=space]" });
+				displayMessage(form, ts.locale.invalidSpaceError, true);
 			}
 		},
 		changePassword: function(username, password, npassword, form) {
@@ -343,8 +341,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 			};
 			var pwErrback = function() {
 				var msg = "Old password is incorrect.";
-				displayMessage(form, msg, true, { selector:
-					"[name=password]" });
+				displayMessage(form, msg, true);
 			};
 			var user = new tiddlyweb.User(username, password, "/");
 			user.setPassword(npassword, pwCallback, pwErrback);
@@ -380,17 +377,11 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 				var newPass2 = $("[name=new_password_confirm]").val();
 				if(newPass !== newPass2) {
 					var msg = "Passwords do not match";
-					displayMessage(form, msg, true,
-						{ selector: "[name=new_password], " +
-							"[name=new_password_confirm]" });
+					displayMessage(form, msg, true);
 				} else if(newPass.length < 6) {
-					displayMessage(form,
-						ts.locale.passwordLengthError, true,
-						{ selector: "[name=new_password], " +
-							"[name=new_password_confirm]" });
+					displayMessage(form, ts.locale.passwordLengthError, true);
 				} else {
-					ts.changePassword(ts.user.name, oldPass,
-						newPass, form);
+					ts.changePassword(ts.user.name, oldPass, newPass, form);
 				}
 				return false;
 			});
@@ -415,8 +406,7 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 				};
 				var errback = function(xhr, error, exc) {
 					var msg = "Unable to include space with that name.";
-					displayMessage(form, msg, true,
-						{ selector: "[name=spacename]" });
+					displayMessage(form, msg, true);
 				};
 				new tiddlyweb.Space(ts.currentSpace, "/").includes().
 					add(space, callback, errback);
@@ -443,15 +433,14 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 						displayMessage(form,
 							"Unable to add members from a space you " +
 							"are not a member of",
-							true, { selector: "[name=username]" });
+							true);
 					} else if (xhr.status === 409) {
 						displayMessage(form,
 							"Unknown username entered.",
-							true, { selector: "[name=username]" });
+							true);
 					} else {
 						var msg = "Unknown error occurred.";
-						displayMessage(form, msg, true,
-								{ selector: "[name=username]" });
+						displayMessage(form, msg, true);
 					}
 				};
 				if (!spaceName) {
@@ -475,13 +464,11 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 					var host = ts.getHost(spaceName),
 						msg = "Successfully created <a href='" +
 							host + "'>" + host + "</a>.";
-					displayMessage(form, msg, false,
-						{ selector: selector });
+					displayMessage(form, msg, false);
 				};
 				var errback = function() {
 					var msg = "Problem creating a space with that name.";
-					displayMessage(form, msg, true,
-						{ selector: selector });
+					displayMessage(form, msg, true);
 				};
 				ts.createSpace(form, spaceName, callback, errback);
 			});
@@ -590,16 +577,13 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 				var user = $("input[name=username]", form).val();
 				var pass = $("input[name=password]", form).val();
 				if(!user) {
-					return displayMessage(form,
-						"Please provide a username!");
+					return displayMessage(form, "Please provide a username!");
 				}
 				if(!pass) {
-					return displayMessage(form,
-						"Please provide a password!");
+					return displayMessage(form, "Please provide a password!");
 				}
 				options.redirect = $("input[name=redirect]", form).val();
-				ts.login(user,
-					pass, options);
+				ts.login(user, pass, options);
 				ev.preventDefault();
 			});
 		}
